@@ -62,7 +62,7 @@
 		      * require consumer to be updated (as long as this number
 		      * is zero, the API is not considered stable and can
 		      * change without a bump of the major version) */
-#define MINVERSION 1 /* API compatible, ABI may change, functional
+#define MINVERSION 2 /* API compatible, ABI may change, functional
 		      * enhancements only, consumer can be left unchanged if
 		      * enhancements are not considered */
 #define PATCHLEVEL 0 /* API / ABI compatible, no functional changes, no
@@ -414,6 +414,9 @@ static void jent_stir_pool(struct rand_data *entropy_collector)
 	union c mixer;
 	unsigned int i = 0;
 
+	/* Ensure that the function implements a constant time operation. */
+	union c throw_away;
+
 	/*
 	 * Store the SHA-1 constants in reverse order to make up the 64 bit
 	 * value -- this applies to a little endian system, on a big endian
@@ -433,6 +436,8 @@ static void jent_stir_pool(struct rand_data *entropy_collector)
 		 */
 		if ((entropy_collector->data >> i) & 1)
 			mixer.u64 ^= constant.u64;
+		else
+			throw_away.u64 ^= constant.u64;
 		mixer.u64 = rol64(mixer.u64, 1);
 	}
 	entropy_collector->data ^= mixer.u64;
@@ -677,6 +682,7 @@ int jent_entropy_init(void)
 		__u64 time2 = 0;
 		__u64 folded = 0;
 		__u64 delta = 0;
+		unsigned int lowdelta = 0;
 
 		jent_get_nstime(&time);
 		jent_fold_time(NULL, time, &folded, 1<<MIN_FOLD_LOOP_BIT);
@@ -708,7 +714,9 @@ int jent_entropy_init(void)
 		if (!(time2 > time))
 			time_backwards++;
 
-		if (!(delta % 100))
+		/* use 32 bit value to ensure compilation on 32 bit arches */
+		lowdelta = time2 - time;
+		if (!(lowdelta % 100))
 			count_mod++;
 
 		/*
@@ -746,7 +754,7 @@ int jent_entropy_init(void)
 	 * than 1 to ensure the entropy estimation
 	 * implied with 1 is preserved
 	 */
-	if (!(delta_sum) > 1)
+	if ((delta_sum) <= 1)
 		return EMINVARVAR;
 
 	/*
