@@ -61,7 +61,7 @@
 #define MINVERSION 0 /* API compatible, ABI may change, functional
 		      * enhancements only, consumer can be left unchanged if
 		      * enhancements are not considered */
-#define PATCHLEVEL 2 /* API / ABI compatible, no functional changes, no
+#define PATCHLEVEL 3 /* API / ABI compatible, no functional changes, no
 		      * enhancements, bug fixes only */
 
 static int Verbosity = 0;
@@ -194,6 +194,12 @@ static void dolog(int severity, const char *fmt, ...)
 	}
 }
 
+static inline void memset_secure(void *s, int c, size_t n)
+{
+	memset(s, c, n);
+	__asm__ __volatile__("" : : "r" (s) : "memory");
+}
+
 /*******************************************************************
  * entropy handler functions
  *******************************************************************/
@@ -236,7 +242,7 @@ static size_t gather_entropy(struct kernel_rng *rng)
 	if (RNDBYTES != ret)
 		dolog(LOG_WARN, "Injected %lu bytes into %s, expected %d",
 			ret, rng->dev, RNDBYTES);
-	memset(buf, 0, RNDBYTES);
+	memset_secure(buf, 0, RNDBYTES);
 
 	return RNDBYTES;
 }
